-- $Id: pgsql_geoip2_locations_tables.sql 695 2019-08-21 01:38:00Z bhockney $
--
-- Schema for geoip version 2 blocks and locations tables. See README.geoip
-- for information on using this file.
--
-- the ip4r extension needs to be installed first
-- CREATE EXTENSION IF NOT EXISTS ip4r;

-- Create blocks table
CREATE TABLE "blocks" (
  "network"                        cidr             NOT NULL,
  "geoname_id"                     integer          DEFAULT NULL,
  "registered_country_geoname_id"  integer          DEFAULT NULL,
  "represented_country_geoname_id" integer          DEFAULT NULL,
-- is_anonymous_proxy and is_satellite_provider are deprecated in this
-- database and may be removed in the future. They have been moved by maxmind
-- to a separate product.
  "is_anonymous_proxy"             boolean          NOT NULL,
  "is_satellite_provider"          boolean          NOT NULL,
--  
  "postal_code"                    text             DEFAULT NULL,
  "latitude"                       double precision DEFAULT NULL,
  "longitude"                      double precision DEFAULT NULL,
  "accuracy_radius"                integer          DEFAULT NULL,
  CONSTRAINT geoip2_blocks_pkey PRIMARY KEY (network)
);
-- Always create the gist index on network and also indices on geoname_id columns,
-- used for joining locations table.
CREATE INDEX "geoip2_blocks_ip4r_network"            ON "blocks" USING gist (iprange(network));
CREATE INDEX "geoip2_geoname_id"                     ON "blocks" (geoname_id);
CREATE INDEX "geoip2_registered_country_geoname_id"  ON "blocks" (registered_country_geoname_id);
CREATE INDEX "geoip2_represented_country_geoname_id" ON "blocks" (represented_country_geoname_id);
-- Create indices below on columns frequently referenced in queries to improve performance.
-- You can create as many or few as you need.
-- CREATE INDEX "geoip2_postal_code"                    ON "blocks" (postal_code);
-- CREATE INDEX "geoip2_latitude"                       ON "blocks" (latitude);
-- CREATE INDEX "geoip2_longitude"                      ON "blocks" (longitude);
-- CREATE INDEX "geoip2_accuracy_radius"                ON "blocks" (accuracy_radius);

-- Create locations table
CREATE TABLE "locations" (
  "geoname_id"             integer NOT NULL,
  "locale_code"            text    NOT NULL,
  "continent_code"         text    DEFAULT NULL,
  "continent_name"         text    DEFAULT NULL,
  "country_iso_code"       text    DEFAULT NULL,
  "country_name"           text    DEFAULT NULL,
  "subdivision_1_iso_code" text    DEFAULT NULL,
  "subdivision_1_name"     text    DEFAULT NULL,
  "subdivision_2_iso_code" text    DEFAULT NULL,
  "subdivision_2_name"     text    DEFAULT NULL,
  "city_name"              text    DEFAULT NULL,
  "metro_code"             integer DEFAULT NULL,
  "time_zone"              text    DEFAULT NULL,
  "is_in_european_union"   boolean NOT NULL,
  CONSTRAINT geoip2_locations_id_locale PRIMARY KEY (geoname_id, locale_code)
);
-- Create indices below on columns frequently referenced in queries to improve performance.
-- You can create as many or few as you need.
-- CREATE INDEX "geoip2_continent_code"         ON "locations" (continent_code);
-- CREATE INDEX "geoip2_continent_name"         ON "locations" (continent_name);
-- CREATE INDEX "geoip2_country_iso_code"       ON "locations" (country_iso_code);
-- CREATE INDEX "geoip2_country_name"           ON "locations" (country_name);
-- CREATE INDEX "geoip2_subdivision_1_iso_code" ON "locations" (subdivision_1_iso_code);
-- CREATE INDEX "geoip2_subdivision_1_name"     ON "locations" (subdivision_1_name);
-- CREATE INDEX "geoip2_subdivision_2_iso_code" ON "locations" (subdivision_2_iso_code);
-- CREATE INDEX "geoip2_subdivision_2_name"     ON "locations" (subdivision_2_name);
-- CREATE INDEX "geoip2_city_name"              ON "locations" (city_name);
-- CREATE INDEX "geoip2_metro_code"             ON "locations" (metro_code);
-- CREATE INDEX "geoip2_time_zone"              ON "locations" (time_zone);

-- vim: set syntax=sql:
