<?php
/*
$Id: functions_geoip.php 727 2023-11-16 20:40:20Z bhockney $
(C) 2003-2023 by Bob Hockney <zeus@ix.netcom.com>

geoip functions for webfwlog

This code is distributed under the terms of GNU GPL
*/
?>
<?php

// Create new reader classes
function geoip2_open (&$config) {
	if(isset($config["geoip2_file"])) {
		try {
			$r = new MaxMind\Db\Reader($config["geoip2_file"]);
			$config["reader_locations"] = $r;
		} catch (Exception $e) {
			if ($config["debug"] == 1)
				print "\n<!-- {$e->getMessage()} -->\n";
			if ($config["debug"] == 2) {
				print "<pre class=report>";
				print "\n{$e->getMessage()}\n";
				print "</pre>";
			}
		}
	}
	if(isset($config["geoip2_asn_file"])) {
		try {
			$r = new MaxMind\Db\Reader($config["geoip2_asn_file"]);
			$config["reader_asns"] = $r;
		} catch (Exception $e) {
			if ($config["debug"] == 1)
				print "\n<!-- {$e->getMessage()} -->\n";
			if ($config["debug"] == 2)
				print "\n{$e->getMessage()}\n";
		}
	}
	return;
}

// Close reader classes if open
function geoip2_fini(&$config) {
	if ($config["reader_locations"])
		$config["reader_locations"]->close();
	if ($config["reader_asns"])
		$config["reader_asns"]->close();
	return;
}

// Return geoip2 value if using local lookup. Not called otherwise.
function geoip2_lookup ($colkey, $value, &$line) {
	global $config, $source, $shortnames, $php_inet_ntop;
	$ret = $value;
	$c = preg_split('/(_s|_d)$/', $colkey,0,PREG_SPLIT_DELIM_CAPTURE);
	try {
		$ip = "";
		if ($source == "syslog" or (isset($config["packet_page"]))) {
			if(isset($line["ip{$c[1]}addr{$config["addr_type"]}"])) {
				if($config["iptype"] == "bin") {
					$ip = $php_inet_ntop($line["ip{$c[1]}addr{$config["addr_type"]}"]); 
				} else {
					$ip = $line["ip{$c[1]}addr{$config["addr_type"]}"];
				}
			}
		} else { 
			if(isset($line["{$shortnames["ip{$c[1]}addr"]}"]))
				$ip = $line["{$shortnames["ip{$c[1]}addr"]}"];
		}
		if ($config["reader_locations"] and !$config["have_locations"])
			$r = $config["reader_locations"]->get($ip);
		else
			$r = null;
		switch ($c[0]) {
			case "continent_code":
				if(isset($r["continent"]["code"]))
					$ret = $r["continent"]["code"];
				break;
			case "continent_name":
				if(isset($r["continent"]["names"]["{$config["geoip2_locale"]}"]))
					$ret = $r["continent"]["names"]["{$config["geoip2_locale"]}"];
				break;
			case "country_iso_code":
				if(isset($r["country"]["iso_code"]))
					$ret = $r["country"]["iso_code"];
				break;
			case "country_name":
				if(isset($r["country"]["names"]["{$config["geoip2_locale"]}"]))
					$ret = $r["country"]["names"]["{$config["geoip2_locale"]}"];
				break;
			case "subdivision_1_iso_code":
				if(isset($r["subdivisions"]["0"]["iso_code"]))
					$ret = $r["subdivisions"]["0"]["iso_code"];
				break;
			case "subdivision_1_name":
				if(isset($r["subdivisions"]["0"]["names"]["{$config["geoip2_locale"]}"]))
					$ret = $r["subdivisions"]["0"]["names"]["{$config["geoip2_locale"]}"];
				break;
			case "subdivision_2_iso_code":
				if(isset($r["subdivisions"]["1"]["iso_code"]))
					$ret = $r["subdivisions"]["1"]["iso_code"];
				break;
			case "subdivision_2_name":
				if(isset($r["subdivisions"]["1"]["names"]["{$config["geoip2_locale"]}"]))
					$ret = $r["subdivisions"]["1"]["names"]["{$config["geoip2_locale"]}"];
				break;
			case "city_name":
				if(isset($r["city"]["names"]["{$config["geoip2_locale"]}"]))
					$ret = $r["city"]["names"]["{$config["geoip2_locale"]}"];
				break;
			case "metro_code":
				if(isset($r["location"]["metro_code"]))
					$ret = $r["location"]["metro_code"];
				break;
			case "time_zone":
				if(isset($r["location"]["time_zone"]))
					$ret = $r["location"]["time_zone"];
				break;
			case "accuracy_radius":
				if(isset($r["location"]["accuracy_radius"]))
					$ret = $r["location"]["accuracy_radius"];
				break;
			case "registered_country_geoname_id":
				if(isset($r["registered_country"]["names"]["{$config["geoip2_locale"]}"]))
					$ret = $r["registered_country"]["names"]["{$config["geoip2_locale"]}"];
				break;
			case "represented_country_geoname_id":
				if(isset($r["represented_country"]["names"]["{$config["geoip2_locale"]}"]))
					$ret = $r["represented_country"]["names"]["{$config["geoip2_locale"]}"];
				break;
			case "is_anonymous_proxy":
				if(is_array($r)) {
					if(isset($r["traits"]["is_anonymous_proxy"]))
						$ret = "Yes";
					else
						$ret = "No";
				} else
					$ret = "";
				break;
			case "is_satellite_provider":
				if(is_array($r)) {
					if(isset($r["traits"]["is_satellite_provider"]))
						$ret = "Yes";
					else
						$ret = "No";
				} else
					$ret = "";
				break;
			case "is_in_european_union":
				if(is_array($r)) {
					if(isset($r["country"]["is_in_european_union"]))
						$ret = "Yes";
					else
						$ret = "No";
				} else
					$ret = "";
				break;
			case "postal_code":
				if(isset($r["postal"]["code"]))
					$ret = $r["postal"]["code"];
				break;
			case "latitude":
				if(isset($r["location"]["latitude"]))
					$ret = $r["location"]["latitude"];
				break;
			case "longitude":
				if(isset($r["location"]["longitude"]))
					$ret = $r["location"]["longitude"];
				break;
			default:
				break;
		}
		if ($config["reader_asns"] and !$config["have_asns"])
			$r = $config["reader_asns"]->get($ip);
		else
			$r = null;
		switch ($c[0]) {
			case "autonomous_system_number":
				if(isset($r["autonomous_system_number"]))
					$ret = $r["autonomous_system_number"];
				break;
			case "autonomous_system_organization":
				if(isset($r["autonomous_system_organization"]))
					$ret = $r["autonomous_system_organization"];
				break;
			default:
				break;
		}
	} catch (Exception $e) {
		print $e->getMessage();
	}
	return $ret;
}

// vim:set ts=4: 
?>
