<?php
/*
$Id: html_out.php 727 2023-11-16 20:40:20Z bhockney $
(C) 2003-2023 by Bob Hockney <zeus@ix.netcom.com>

html output for webfwlog

Webfwlog is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
?>
<!DOCTYPE html>
<html lang="en">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
<title><?php print "{$config["title"]}"; ?></title>
<?php
$dsource = "$self?data_source=".urlencode("{$FWLOG["data_source"]}");
if (isset($FWLOG["data_table"]))
$dsource = "$dsource&amp;data_table=".urlencode("{$FWLOG["data_table"]}");
if (isset($FWLOG["syslog_file"]))
$dsource = "$dsource&amp;syslog_file=".urlencode("{$FWLOG["syslog_file"]}");
$muri = "$dsource";
if (isset($FWLOG["upd_hosts"]) and (!isset($FWLOG["page_length"]) or $FWLOG["page_length"] == 0))
$muri = "$muri&amp;upd_hosts=";
if (isset($FWLOG["populate_cache"]) and (!isset($FWLOG["page_length"]) or $FWLOG["page_length"] == 0))
$muri = "$muri&amp;populate_cache=";
if (isset($FWLOG["populate_cache_all"]) and (!isset($FWLOG["page_length"]) or $FWLOG["page_length"] == 0))
$muri = "$muri&amp;populate_cache_all=";
$muri = "{$muri}&amp;action=run+report&amp;level=$level";

if (isset($FWLOG["refresh"]) and $FWLOG["refresh"]) {
?>
<meta http-equiv="refresh" content="<?php print "{$FWLOG["refresh"]};url=$muri"; ?>">
<?php
}
?>
<LINK REL=StyleSheet HREF="style.css" TYPE="text/css" MEDIA=screen>
</head>

<body>
<?php if ($config["debug"]) include "include/debug.php"; ?>
<h1 class="report"><?php print "{$config["title"]}"; ?></h1>
<?php

if ($source <> "sql")
$link = db("open", "$database");

$rownum = 0;

print "<pre class=\"report\">";

if ($source == "syslog" and $config["debug"] >= 2)
print htmlspecialchars("{$query}", ENT_QUOTES);

if (isset($FWLOG["be_verbose"]) and $config["allow_be_verbose"]) {
	if ($source == "sql") {
		print htmlspecialchars("$o_query", ENT_QUOTES)."\n";
	}

	if ($source == "syslog") {
		print htmlspecialchars("{$query}", ENT_QUOTES);
		print "Exit status: $retval\n";
		print htmlspecialchars("{$prog_params}", ENT_QUOTES)."\n";
		while(true) {
			$line = db("nextrow", $result, "$source");
			if ($line == "%%")
				break;
			print htmlspecialchars("{$line}", ENT_QUOTES)."\n";
			if ($retval) //bad exit status
				break;
		}
	}
} else {
	if ($source == "syslog") {
		while(true) {
			$line = db("nextrow", $result, "$source");
			if ($line == "%%")
				break;
			if ($retval) { //bad exit status
				print htmlspecialchars("{$line}", ENT_QUOTES)."\n";
				break;
			}
		}
	}
}

if ($source == "syslog" and $retval) { //bad exit status
	print "<span class=err_msg>";
	print "Exit status: $retval\n";
	print "syslog parser terminated abnormally\n";
	print "</span>";
	die;
}

if ($source == "syslog") {
	$line = db("nextrow", $result, "$source");
	$config["have_locations"] = $line;
	$line = db("nextrow", $result, "$source");
	$config["have_asns"] = $line;
	$line = db("nextrow", $result, "$source");
}

print "</pre>\n";

// Output Report
{
	if (isset($FWLOG["report_title"]))
		print "<h2 class=\"report\">".htmlspecialchars("{$FWLOG["report_title"]}", ENT_QUOTES)."</h2>\n\n";

	$bg_color1 = "report_r1";
	$bg_color2 = "report_r2";

	$bg_color = $bg_color1;

	print "<div class=\"align_center\">\n";
	print "<table class=\"align_table\">\n";

	print "\t<tr><td class=align_left>\n";
	print "\t\t<a href=\"$dsource\">Home</a>&nbsp;\n";
	print "\t\t<a href=\"$self?action=use+report&amp;select_report=".urlencode($FWLOG["report"])."&amp;level=$level&amp;drill_down=yes\">Edit this report</a>&nbsp;\n";
	print "\t</td></tr>\n";

	print "\t<tr><td><table>\n";

	if ($source == "syslog") {
		$temp = $shortnames;
	} else {
		$temp = array_flip($shortnames);
	}

	if ($source == "syslog")
		$db_data = $source;
	else
		$db_data = $link;
	
	$colnum = 0;
	while ($name = db("nextfield", $result, $db_data)) {
		if ("$name" == "ip_saddr_t" or "$name" == "ip_daddr_t" or "$name" == "oob_family_t" or "$name" == "ip_protocol_t"
			or "$name" == "tcp_sport_t" or "$name" == "udp_sport_t" or "$name" == "tcp_dport_t" or "$name" == "udp_dport_t"
			or "$name" == "count_t")
			continue;
		if (!isset($FWLOG["c_sname"]) and "$name" == "{$shortnames["sname"]}")
			continue; 
		$fields[] = "$name";
	}

	print "\t<tr>\n";
	foreach ($fields as $col) {
		if ($source == "syslog") {
			$name = "$col";
		} else {
			$name = "{$temp["$col"]}";
		}

		if ("$name" == "sname" and !isset($FWLOG["c_sname"]))
			continue;
		if (!isset($FWLOG["c_oob_family"]) and "$name" == "oob_family")
			continue; 

		switch ("$name") {
			case "dst_host":	// Would never sort
			case "src_host":	// by these so no
			case "dst_service":	// link in header
			case "src_service":	//
				print "\t\t<th class=\"$bg_color report_row\">{$shortnames["$name"]}</th>\n";
					break;
			default:
				$s = "s_$name";
				$o = "o_$name";
				$h_uri = "$muri&amp;drilldown=yes&amp;start=0&amp;$s=0";
				if (isset($FWLOG["$s"]) and $FWLOG["$s"] == 1)
					if (isset($FWLOG["$o"])) {
						$h_uri = "$h_uri&amp;$o=";
					} else {
						$h_uri = "$h_uri&amp;$o=on";
					}
				print "\t\t<th class=\"$bg_color report_row\"><A HREF=\"$h_uri\">{$shortnames["$name"]}</A></th>\n";
				break;
		}
	}
	print "\t</tr>\n";

	if ($source == "syslog")
		$rownum = $rownum + 1;

	while ($line = db("nextrow", $result, "$source")) {

		switch ($bg_color) {
			case $bg_color1: $bg_color = $bg_color2; break;
			case $bg_color2: $bg_color = $bg_color1; break;
		}

		print "\t<tr>\n";
		$family = AF_INET;
		foreach ($line as $column => $value) {
			//format dates
			switch ("$column") {
				// database
				case "{$shortnames['oob_time_sec']}":
				case "{$shortnames['local_time']}":
				case "{$shortnames['earliest']}":
				case "{$shortnames['latest']}":
				case "{$shortnames['oob_earliest']}":
				case "{$shortnames['oob_latest']}":
				// syslog
				case "local_time":
				case "earliest":
				case "latest":
					$value = date("{$config["dformat"]}", $value);
					break;
				default:
					break;	
			}

			if ("$column" == "ip_saddr_t" or "$column" == "ip_daddr_t" or "$column" == "ip_protocol_t"
				or "$column" == "tcp_sport_t" or "$column" == "udp_sport_t"
				or "$column" == "tcp_dport_t" or "$column" == "udp_dport_t"
				or "$column" == "count_t")
				continue;
			if ($source == "syslog") {
				$l = "l_$column";
				$colkey = $column;
				if ("$colkey" == "oob_family") {
					$family = $line["oob_family"];
					if (!isset($FWLOG["c_oob_family"]))
						continue;
				}
			} else {
				if("$column" == "oob_family_t") {
					$family = $value;
					continue;
				} elseif("$column" == "oob_family") {
					$family = $value;
				}
				$l = "l_{$temp["$column"]}";
				$colkey = $temp["$column"];
			}

			if ("$colkey" == "sname" and !isset($FWLOG["c_sname"]))
				continue;

			if (is_numeric($value) and isset($config["format.$colkey"]))
				$value = sprintf($config["format.$colkey"], $value);

			$extra_class = "";
			if ($colkey == "raw_mac") {
				$value = chunk_split($value, 3, " ");
				$extra_class = "mac_str";
			}
			$count = "";
			if (("$colkey" == "dport" or "$colkey" == "sport") and $value > 65535 ) {
				print "\t\t<td class=\"report_row $bg_color\"></td>\n";
			} else {
				$s = "";
				if (!isset($FWLOG["summarize"]))
					if($source == "syslog") {
						$s = trim("{$line['sname']}");
					} else {
						$s = trim("{$line[$shortnames['sname']]}");
					}
				if (isset($FWLOG["$l"])) { // add link if requested
					$a = makewhere("$colkey", "$value", "$s", "$family");
					$uri = "$muri";
					$uri .= "&amp;drilldown=yes&amp;start=0";
					if ($source <> "syslog" and isset($FWLOG["w_extra"]) and
						! preg_match ('/&amp;w_extra=/', "$a"))
							$uri .= "&amp;w_extra=".urlencode("{$FWLOG["w_extra"]}");
					$uri .= "$a";
					if(isset($geoip_columns["$colkey"]))
						print "\t\t<td class=\"report_row $bg_color $extra_class\"><A HREF=\"$uri\">".htmlspecialchars(get_geoip_value($colkey, $value, $line), ENT_QUOTES)."</A></td>\n";
					else
						print "\t\t<td class=\"report_row $bg_color $extra_class\"><A HREF=\"$uri\">".htmlspecialchars("$value", ENT_QUOTES)."</A></td>\n";

				} else { 
					if(isset($geoip_columns["$colkey"]))
						print "\t\t<td class=\"report_row $bg_color $extra_class\">".htmlspecialchars(get_geoip_value($colkey, $value, $line), ENT_QUOTES)."</td>\n";
					else
						print "\t\t<td class=\"report_row $bg_color $extra_class\">".htmlspecialchars("$value", ENT_QUOTES)."</td>\n";
				}
			}
		}
		print "\t</tr>\n";
	}

	if ($source == "syslog") {
		$matched_rows = $result[$rownum];
		$rownum = $rownum + 1;
		$matched_records = $result[$rownum];
		$rownum = $rownum + 1;
		$included_records = $result[$rownum];
		$rownum = $rownum + 1;
		$hostupdatetime = $result[$rownum];
		$rownum = $rownum + 1;
		$servicesupdatetime = $result[$rownum];
		$rownum = $rownum + 1;
		$cachepopulatetime = $result[$rownum];
		$rownum = $rownum + 1;

		$querytime = $querytime - $hostupdatetime - $servicesupdatetime - $cachepopulatetime;
	}

	geoip2_close($config);

	flush();

	// add paging links on LIMITed report
	if (isset($FWLOG["page_length"]) and $FWLOG["page_length"] > 0) {
		if ($matched_rows > $FWLOG["page_length"]) {
			print "<tr>\n";
			print "<td class=\"report_sum\" colspan=" . count($fields) .">\n";
			print_scrollbar("$muri&amp;start=",$start,$matched_rows,$FWLOG["page_length"],count($fields) * 4);
			print "</td>\n";
			print "</tr>\n";
		}
	}

	print "<tr>\n";
	print "<td class=\"report_sum\" colspan=" . count($fields) .">";
	if (isset($FWLOG["page_length"]) and $FWLOG["page_length"] > 0) {
		$begin = $start + 1;
		$end = min($start + $FWLOG["page_length"], $matched_rows);
		print "Rows $begin to $end of $matched_rows displayed";
	} else {
		print "$matched_rows rows returned";
	}
	print "</td>";
	print "</tr>\n";

	if (isset($FWLOG["summarize"])) {
		if ($matched_records <> $included_records) {
			print "<tr>\n";
			print "<td class=\"report_sum\" colspan=" . count($fields) .">";
			print "$included_records entries included in report of $matched_records matched log entries";
			print "</td>";
			print "</tr>\n";
		} else {
			print "<tr>\n";
			print "<td class=\"report_sum\" colspan=" . count($fields) .">";
			print "$matched_records logged entries matched";
			print "</td>";
			print "</tr>\n";
		}
	}

	print "</table></td></tr>\n";
	print "</table>\n";
	print "</div>\n";

	print "<p>";

	$reporttime = time() - $time -  $querytime - $hostupdatetime - $servicesupdatetime - $cachepopulatetime;
	$totaltime = time() - $time;

	if (isset($FWLOG["upd_hosts"])) {
		print "Host update time was $hostupdatetime Seconds<br>\n";
		print "Services update time was $servicesupdatetime Seconds<br>\n";
	}

	if (isset($FWLOG["populate_cache"]) or isset($FWLOG["populate_cache_full"])) {
		if (! isset($FWLOG["upd_hosts"]))
			$cachepopulatetime += $hostupdatetime + $servicesupdatetime;
		print "Cache Populate time was $cachepopulatetime Seconds<br>\n";
	}

	print "Query time was $querytime Seconds.<br>\n";
	print "Report time was $reporttime Seconds.<br>\n";
	print "Total time was $totaltime Seconds.<br>\n";
}

if($source == "sql") {
	db("statement", "DROP TABLE $output", $link);
	db("statement", "DROP TABLE $allrows", $link);
}

db("close", $link);

?>
<p>
<em><a class="report_footer" href="http://www.webfwlog.net">Generated by webfwlog <?php print "$webfwlog_version"; ?></a></em>

</body>
</html>

<!-- vim:set ts=4: -->
